services:
  slack:
    container_name: {{ instance_name }}-slack-bridge
    image: dock.mau.dev/mautrix/slack:latest
    networks:
      - {{ instance_name }}_mindroom-network
      - mynetwork
    ports:
      - "{{ port }}:29317"
    restart: unless-stopped
    volumes:
      - {{ data_dir }}/data:/data

networks:
  {{ instance_name }}_mindroom-network:
    external: true
  mynetwork:
    external: true
